"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ObjectNodeController = void 0;
const tslib_1 = require("tslib");
const authentication_1 = require("@loopback/authentication");
const authorization_1 = require("@loopback/authorization");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const models_1 = require("../models");
const application_service_1 = require("../services/application.service");
const access_rights_const_1 = require("./../services/access-rights/access-rights.const");
const object_node_content_service_1 = require("./../services/object-node-content.service");
const object_node_service_1 = require("./../services/object-node.service");
let ObjectNodeController = class ObjectNodeController {
    constructor(objectNodeService, objectNodeContentService) {
        this.objectNodeService = objectNodeService;
        this.objectNodeContentService = objectNodeContentService;
    }
    create(objectNode, ctx) {
        return this.objectNodeService.add(objectNode, ctx);
    }
    updateById(id, objectNode, ctx) {
        return this.objectNodeService.modifyById(id, objectNode, ctx);
    }
    async deleteById(id, ctx) {
        await this.objectNodeService.removeById(id, ctx);
    }
    async downloadFile(id, contentType, contentId, response, ctx) {
        switch (contentType) {
            case 'file':
                // eslint-disable-next-line no-case-declarations
                const file = (await this.objectNodeContentService.getContent(id, 'contentFile', 'ContentFile', {
                    contentId: contentId,
                }, ctx));
                response.download(file.filePath, file.fileName);
                return response;
            default:
                // eslint-disable-next-line no-case-declarations
                const contentTypeExtension = contentType.charAt(0).toUpperCase() + contentType.substr(1);
                // eslint-disable-next-line no-case-declarations
                const text = (await this.objectNodeContentService.getContent(id, 'content' + contentTypeExtension, 'Content' + contentTypeExtension, {
                    contentId: contentId,
                }, ctx));
                response.setHeader('Content-Type', 'text/plain; charset=utf-8');
                response.write(text);
                response.end();
                return response;
        }
    }
};
tslib_1.__decorate([
    authentication_1.authenticate('jwt'),
    authorization_1.authorize({
        resource: access_rights_const_1.AccessRightsEntity.objectNode,
        scopes: [access_rights_const_1.AccessRightsScope.create],
    }),
    rest_1.post('/object-nodes', {
        responses: {
            '200': {
                description: 'ObjectNode model instance',
                content: { 'application/json': { schema: rest_1.getModelSchemaRef(models_1.ObjectNode) } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.ObjectNode, {
                    title: 'NewObjectNode',
                    exclude: ['id'],
                }),
            },
        },
    })),
    tslib_1.__param(1, core_1.inject(application_service_1.CURRENT_CONTEXT)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object, application_service_1.CurrentContext]),
    tslib_1.__metadata("design:returntype", Promise)
], ObjectNodeController.prototype, "create", null);
tslib_1.__decorate([
    authentication_1.authenticate('jwt'),
    authorization_1.authorize({
        resource: access_rights_const_1.AccessRightsEntity.objectNode,
        scopes: [access_rights_const_1.AccessRightsScope.update],
    }),
    rest_1.patch('/object-nodes/{id}', {
        responses: {
            '204': {
                description: 'ObjectNode PATCH success',
                content: { 'application/json': { schema: rest_1.getModelSchemaRef(models_1.ObjectNode) } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.requestBody({
        content: {
            'application/json': {
                schema: rest_1.getModelSchemaRef(models_1.ObjectNode, { partial: true }),
            },
        },
    })),
    tslib_1.__param(2, core_1.inject(application_service_1.CURRENT_CONTEXT)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.ObjectNode,
        application_service_1.CurrentContext]),
    tslib_1.__metadata("design:returntype", Promise)
], ObjectNodeController.prototype, "updateById", null);
tslib_1.__decorate([
    authentication_1.authenticate('jwt'),
    authorization_1.authorize({
        resource: access_rights_const_1.AccessRightsEntity.objectNode,
        scopes: [access_rights_const_1.AccessRightsScope.delete],
    }),
    rest_1.del('/object-nodes/{id}', {
        responses: {
            '204': {
                description: 'ObjectNode DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, core_1.inject(application_service_1.CURRENT_CONTEXT)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, application_service_1.CurrentContext]),
    tslib_1.__metadata("design:returntype", Promise)
], ObjectNodeController.prototype, "deleteById", null);
tslib_1.__decorate([
    authorization_1.authorize({
        resource: access_rights_const_1.AccessRightsEntity.objectNodeContent,
        scopes: [access_rights_const_1.AccessRightsScope.read],
    }),
    rest_1.get('/object-nodes/{id}/content-{contentType}/{contentId}'),
    rest_1.oas.response.file(),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.path.string('contentType')),
    tslib_1.__param(2, rest_1.param.path.string('contentId')),
    tslib_1.__param(3, core_1.inject(rest_1.RestBindings.Http.RESPONSE)),
    tslib_1.__param(4, core_1.inject(application_service_1.CURRENT_CONTEXT)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, String, String, Object, application_service_1.CurrentContext]),
    tslib_1.__metadata("design:returntype", Promise)
], ObjectNodeController.prototype, "downloadFile", null);
ObjectNodeController = tslib_1.__decorate([
    tslib_1.__param(0, core_1.service(object_node_service_1.ObjectNodeService)),
    tslib_1.__param(1, core_1.service(object_node_content_service_1.ObjectNodeContentService)),
    tslib_1.__metadata("design:paramtypes", [object_node_service_1.ObjectNodeService,
        object_node_content_service_1.ObjectNodeContentService])
], ObjectNodeController);
exports.ObjectNodeController = ObjectNodeController;
//# sourceMappingURL=object-node.controller.js.map