"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContextInterceptor = void 0;
const tslib_1 = require("tslib");
const context_1 = require("@loopback/context");
const core_1 = require("@loopback/core");
const lodash_1 = require("lodash");
const application_service_1 = require("../services/application.service");
const application_error_1 = require("./../helper/application-error");
const access_rights_service_1 = require("./../services/access-rights/access-rights.service");
const abstract_interceptor_1 = require("./abstract.interceptor");
const constants_1 = require("./constants");
/**
 * This class will be bound to the application as an `Interceptor` during
 * `boot`
 */
let ContextInterceptor = class ContextInterceptor extends abstract_interceptor_1.AbstractInterceptor {
    constructor(accessRightsService, ctx) {
        super();
        this.accessRightsService = accessRightsService;
        this.ctx = ctx;
    }
    /**
     * This method is used by LoopBack context to produce an interceptor function
     * for the binding.
     *
     * @returns An interceptor function
     */
    value() {
        return this.intercept.bind(this);
    }
    /**
     * The logic to intercept an invocation
     * @param invocationCtx - Invocation context
     * @param next - A function to invoke next interceptor or the target method
     */
    async intercept(invocationCtx, next) {
        var _a, _b, _c, _d;
        // eslint-disable-next-line no-useless-catch
        try {
            // Add pre-invocation logic here
            const result = await next();
            // Add post-invocation logic here
            if (Array.isArray(result)) {
                if (result.length > 0) {
                    if ((_a = result[0]) === null || _a === void 0 ? void 0 : _a.uri) {
                        const uriParts = await this.getUriParts(invocationCtx);
                        const entityName = this.getEntityName((_b = result[0]) === null || _b === void 0 ? void 0 : _b.uri, uriParts.baseUri);
                        await this.accessRightsService.cleanReturnedEntities(entityName, result, this.ctx);
                    }
                    else {
                        throw application_error_1.ApplicationError.forbiden();
                    }
                }
            }
            else if (lodash_1.isObject(result)) {
                const entity = result;
                if (entity === null || entity === void 0 ? void 0 : entity.uri) {
                    const uriParts = await this.getUriParts(invocationCtx);
                    const entityName = this.getEntityName(entity.uri, uriParts.baseUri);
                    await this.accessRightsService.cleanReturnedEntity(entityName, result, this.ctx);
                }
                else {
                    throw application_error_1.ApplicationError.forbiden();
                }
                if (!((_d = (_c = entity.aclCtx) === null || _c === void 0 ? void 0 : _c.rights) === null || _d === void 0 ? void 0 : _d.read)) {
                    throw application_error_1.ApplicationError.forbiden();
                }
            }
            return result;
        }
        catch (err) {
            // Add error handling logic here
            if (!err.statusCode) {
                throw application_error_1.ApplicationError.unexpectedError(err);
            }
            throw err;
        }
    }
};
ContextInterceptor = tslib_1.__decorate([
    core_1.globalInterceptor(constants_1.CONTEXT_INTERCEPTOR, { tags: { name: 'Context' } }),
    tslib_1.__param(0, core_1.service(access_rights_service_1.AccessRightsService)),
    tslib_1.__param(1, context_1.inject(application_service_1.CURRENT_CONTEXT)),
    tslib_1.__metadata("design:paramtypes", [access_rights_service_1.AccessRightsService,
        application_service_1.CurrentContext])
], ContextInterceptor);
exports.ContextInterceptor = ContextInterceptor;
//# sourceMappingURL=context.interceptor.js.map