"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccessRightTreeService = void 0;
const tslib_1 = require("tslib");
const authorization_1 = require("@loopback/authorization");
const core_1 = require("@loopback/core");
const entity_name_1 = require("../../models/entity-name");
const object_node_service_1 = require("./../object-node.service");
const access_rights_abtract_service_1 = require("./access-rights-abtract.service");
const access_rights_tree_const_1 = require("./access-rights-tree.const");
const access_rights_const_1 = require("./access-rights.const");
const access_rights_service_1 = require("./access-rights.service");
let AccessRightTreeService = class AccessRightTreeService extends access_rights_abtract_service_1.AccessRightAbstractService {
    constructor(accessRightsService, objectNodeService) {
        super(accessRightsService, entity_name_1.EntityName.objectTree);
        this.accessRightsService = accessRightsService;
        this.objectNodeService = objectNodeService;
    }
    async authorizeRead(ctx, context) {
        let treeNode = null;
        if (1 < context.scopes.length) {
            switch (context.scopes[1]) {
                case access_rights_tree_const_1.AccessRightsTreeScope.searchOwner:
                    // eslint-disable-next-line @typescript-eslint/no-unused-vars
                    treeNode = await ctx.treeContext.treeNode.getOrSetValue(async () => {
                        return this.objectNodeService.searchOwner(context.invocationContext.args[0], context.invocationContext.args[1]);
                    });
                    break;
                case access_rights_tree_const_1.AccessRightsTreeScope.searchNamespace:
                    // eslint-disable-next-line @typescript-eslint/no-unused-vars
                    treeNode = await ctx.treeContext.treeNode.getOrSetValue(async () => {
                        return this.objectNodeService.searchNamespace(context.invocationContext.args[0], context.invocationContext.args[1], context.invocationContext.args[2], context.invocationContext.args[3]);
                    });
                    break;
                case access_rights_tree_const_1.AccessRightsTreeScope.searchTreeNode:
                    // eslint-disable-next-line @typescript-eslint/no-unused-vars
                    treeNode = await ctx.treeContext.treeNode.getOrSetValue(async () => {
                        return this.objectNodeService.searchTreeNode(context.invocationContext.args[0], context.invocationContext.args[1], context.invocationContext.args[2], context.invocationContext.args[3], context.invocationContext.args[4], context.invocationContext.args[5]);
                    });
                    break;
            }
        }
        else {
            treeNode = await ctx.treeContext.treeNode.getOrSetValue(async () => {
                return this.objectNodeService.searchById(context.invocationContext.args[0]);
            });
        }
        if (treeNode) {
            return (await this.accessRightsService.hasNodeAccessRight(access_rights_const_1.AccessRightsScope.read, treeNode, ctx))
                ? authorization_1.AuthorizationDecision.ALLOW
                : authorization_1.AuthorizationDecision.DENY;
        }
        return authorization_1.AuthorizationDecision.DENY;
    }
    async authorizeCreate(ctx, context) {
        return authorization_1.AuthorizationDecision.DENY;
    }
    async authorizeUpdate(ctx, context) {
        return authorization_1.AuthorizationDecision.DENY;
    }
    async authorizeDelete(ctx, context) {
        return authorization_1.AuthorizationDecision.DENY;
    }
    async cleanReturnedEntity(entity, ctx) {
        const tree = entity;
        tree.aclCtx = {
            rights: await this.accessRightsService.getNodeAccessRights(tree.treeNode, ctx),
        };
        if (tree.aclCtx.rights.read) {
            await this.accessRightsService.cleanReturnedEntities(entity_name_1.EntityName.objectTree, tree.children, ctx);
        }
        else {
            tree.children = [];
        }
        await this.accessRightsService.cleanReturnedEntity(entity_name_1.EntityName.objectNode, tree.treeNode, ctx);
    }
};
AccessRightTreeService = tslib_1.__decorate([
    core_1.injectable({ scope: core_1.BindingScope.SINGLETON }),
    tslib_1.__param(0, core_1.service(access_rights_service_1.AccessRightsService)),
    tslib_1.__param(1, core_1.service(object_node_service_1.ObjectNodeService)),
    tslib_1.__metadata("design:paramtypes", [access_rights_service_1.AccessRightsService,
        object_node_service_1.ObjectNodeService])
], AccessRightTreeService);
exports.AccessRightTreeService = AccessRightTreeService;
//# sourceMappingURL=access-rights-tree.service.js.map